@@ -11,6 +11,8 @@
 #' @template param_domain
 #' @template param_codomain
 #' @template param_xdt
+#' @template param_check_values
+#' @template param_constants
 #' @export
 Objective = R6Class("Objective",
   public = list(
@@ -30,6 +32,10 @@ Objective = R6Class("Objective",
     #' Specifies codomain of function, hence its feasible values.
     codomain = NULL,
 
+    #' @field constants ([paradox::ParamSet]).\cr
+    #' Changeable constants or parameters that are not subject to tuning can be stored and accessed here.
+    constants = NULL,
+
     #' @field check_values (`logical(1)`)\cr
     check_values = NULL,
 
@@ -38,16 +44,14 @@ Objective = R6Class("Objective",
     #'
     #' @param id (`character(1)`).
     #' @param properties (`character()`).
-    #' @param check_values (`logical(1)`)\cr
-    #' Should points before the evaluation and the results be checked for
-    #' validity?
     initialize = function(id = "f", properties = character(), domain,
       codomain = ParamSet$new(list(ParamDbl$new("y", tags = "minimize"))),
-      check_values = TRUE) {
+      constants = ParamSet$new(), check_values = TRUE) {
       self$id = assert_string(id)
       self$domain = assert_param_set(domain)
       self$codomain = assert_codomain(codomain)
       self$properties = assert_subset(properties, bbotk_reflections$objective_properties)
+      self$constants = assert_param_set(constants)
       self$check_values = assert_flag(check_values)
     },
 
@@ -67,6 +71,10 @@ Objective = R6Class("Objective",
       print(self$domain)
       catf("Codomain:")
       print(self$codomain)
+      if (length(self$constants$values) > 0) {
+        catf("Constants:")
+        print(self$constants)
+      }
     },
 
     #' @description
