@@ -17,6 +17,7 @@
 #' }
 #'
 #' @family Terminator
+#' @template param_archive
 #' @export
 #' @examples
 #' stop_time = as.POSIXct("2030-01-01 00:00:00")
@@ -34,20 +35,27 @@ TerminatorClockTime = R6Class("TerminatorClockTime",
         ParamUty$new("stop_time", tags = "required",
           custom_check = custom_check)
       ))
-      super$initialize(param_set = ps, properties = c("single-crit",
-        "multi-crit"))
+      super$initialize(param_set = ps, properties = c("single-crit", "multi-crit"))
+      self$unit = "seconds"
     },
 
     #' @description
     #' Is `TRUE` iff the termination criterion is positive, and `FALSE`
     #' otherwise.
-    #'
-    #' @param archive ([Archive]).
-    #'
     #' @return `logical(1)`.
     is_terminated = function(archive) {
       return(Sys.time() >= self$param_set$values$stop_time)
     }
+  ),
+
+  private = list(
+    .status = function(archive) {
+      max_steps =  as.integer(ceiling(difftime(self$param_set$values$stop_time,
+        archive$start_time, units = "secs")))
+      current_steps =  as.integer(difftime(Sys.time(), archive$start_time),
+        units = "secs")
+      c("max_steps" = max_steps, "current_steps" = current_steps)
+    }
   )
 )
 
