@@ -18,6 +18,7 @@
 #' }
 #'
 #' @family Terminator
+#' @template param_archive
 #' @export
 #' @examples
 #' trm("combo",
@@ -44,15 +45,15 @@ TerminatorCombo = R6Class("TerminatorCombo",
         tags = "required")))
       ps$values = list(any = TRUE)
       properties = Reduce(intersect, map(terminators, "properties"))
+      properties = properties[properties != "progressr"]
       super$initialize(param_set = ps, properties = properties)
+      self$unit = "percent"
     },
 
     #' @description
     #' Is `TRUE` iff the termination criterion is positive, and `FALSE`
     #' otherwise.
     #'
-    #' @param archive ([Archive]).
-    #'
     #' @return `logical(1)`.
     is_terminated = function(archive) {
       g = if (self$param_set$values$any) any else all
@@ -67,8 +68,39 @@ TerminatorCombo = R6Class("TerminatorCombo",
       super$print(...)
       catf(str_indent("* Terminators:", paste(map_chr(self$terminators, format),
         collapse = ",")))
-    }
+    },
 
+    #' @description
+    #' Returns the remaining runtime in seconds. If `any = TRUE`, the remaining
+    #' runtime is determined by the time-based terminator with the shortest time
+    #' remaining. If non-time-based terminators are used and `any = FALSE`,
+    #' the the remaining runtime is always `Inf`.
+    #' @return `integer(1)`.
+    remaining_time = function(archive) {
+      min_max = if(self$param_set$values$any) min else max
+      min_max(map_dbl(self$terminators, function(t) t$remaining_time(archive)), na.rm = TRUE)
+    },
+
+    #' @description
+    #' Returns `max_steps` and `current_steps` for each terminator.
+    #' @return [data.table::data.table].
+    status_long = function(archive) {
+      map_dtr(self$terminators, function(t) {
+        cbind(as.data.table(as.list(t$status(archive))), unit = t$unit)
+      })
+    }
+  ),
+
+  private = list(
+    .status = function(archive) {
+      max_steps = 100
+      min_max = if(self$param_set$values$any) max else min
+      current_steps = min_max(map_int(self$terminators, function(t) {
+        status = t$status(archive)
+        as.integer(status["current_steps"]/status["max_steps"]*100)
+        }))
+      c("max_steps" = max_steps, "current_steps" = current_steps)
+    }
   )
 )
 
